@@ -1,4 +1,5 @@
-
+import sys
+sys.path.append('.')
 # imports -------------------------------------------------
 import os
 from enum import Enum
@@ -308,12 +309,16 @@ class NautilusMenu:
         py_file.write(code)
         py_file.close()
 
-# Testing area
+# Testing section...
 
 try:
     def remove_linux_menu(name):
-        save_loc = os.path.join(os.path.expanduser('~'), '.local/share/nautilus-python/extensions', name + '*')
-        os.system('rm "{}"'.format(save_loc))
+        save_loc = os.path.join(os.path.expanduser('~'), '.local/share/nautilus-python/extensions', name)
+        try:
+            os.remove(save_loc + '.py')
+            os.remove(save_loc + '.pyc')
+        except Exception as e:
+            print(e)
 
 except:
     pass
